@@ -1,6 +1,5 @@
+from pathlib import Path
 from typing import Type, Dict, Any
-from zipfile import Path
-
 from progress.bar import Bar
 from pydantic import Field, BaseModel
 from pyimporters_plugins.base import KnowledgeParserOptions, KnowledgeParserBase, Concept
